@@ -1,4 +1,4 @@
-from project.utils.serializers import CustomSerializer
+from bluedot_rest_framework.utils.serializers import CustomSerializer
 from .models import Category
 
 
