@@ -3,7 +3,7 @@ from rest_framework.decorators import (action)
 from rest_framework.viewsets import ModelViewSet
 from rest_framework.generics import ListAPIView
 from rest_framework.response import Response
-from project.utils.func import get_tree
+from .func import get_tree
 from .jwt_token import jwt_get_userid_handler, jwt_get_openid_handler, jwt_get_unionid_handler
 
 
